pub async fn claim(
conn: &mut PgConnection,
token: &DbSecret,
claimed_by_user_id: Uuid,
) -> ModelResult<bool>Expand description
Marks the token claimed by the account. Returns false if another claim already won the race.
pub async fn claim(
conn: &mut PgConnection,
token: &DbSecret,
claimed_by_user_id: Uuid,
) -> ModelResult<bool>Marks the token claimed by the account. Returns false if another claim already won the race.